==> jc-1.4.0.tar.gz: javax/net/ssl/SSLSocketFactory.h <==
// public abstract class javax.net.ssl.SSLSocketFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ae720b2f6afde56 javax_net_SocketFactory
// @dep_class eb7a976ef44a2e8c javax_net_ssl_SSLSocketFactory

// header file dependencies
// @dep_header javax_net_SocketFactory

#include "javax/net/SocketFactory.h"

#ifndef _JC_javax_net_ssl_SSLSocketFactory_H_
#define _JC_javax_net_ssl_SSLSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_Socket$object;
struct _jc_javax_net_SocketFactory$object;
struct _jc_javax_net_ssl_SSLContext$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLSocketFactory$sub_refs	_jc_javax_net_ssl_SSLSocketFactory$sub_refs;
typedef struct _jc_javax_net_ssl_SSLSocketFactory$sub_nonrefs	_jc_javax_net_ssl_SSLSocketFactory$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLSocketFactory$refs	_jc_javax_net_ssl_SSLSocketFactory$refs;
typedef struct _jc_javax_net_ssl_SSLSocketFactory$nonrefs	_jc_javax_net_ssl_SSLSocketFactory$nonrefs;
typedef struct _jc_javax_net_ssl_SSLSocketFactory$object	_jc_javax_net_ssl_SSLSocketFactory$object;

typedef struct _jc_javax_net_ssl_SSLSocketFactory$fields_struct	_jc_javax_net_ssl_SSLSocketFactory$fields_struct;
typedef const struct _jc_javax_net_ssl_SSLSocketFactory$vmethods	_jc_javax_net_ssl_SSLSocketFactory$vmethods;
typedef const struct _jc_javax_net_ssl_SSLSocketFactory$vtable	_jc_javax_net_ssl_SSLSocketFactory$vtable;
typedef const struct _jc_javax_net_ssl_SSLSocketFactory$vtype	_jc_javax_net_ssl_SSLSocketFactory$vtype;

// Class fields structure
struct _jc_javax_net_ssl_SSLSocketFactory$fields_struct {
	struct _jc_javax_net_ssl_SSLContext$object	*context;
};
extern _jc_javax_net_ssl_SSLSocketFactory$fields_struct _jc_javax_net_ssl_SSLSocketFactory$class_fields;

// Constructors
extern void _jc_javax_net_ssl_SSLSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *);

// Virtual methods
extern struct _jc_java_net_Socket$object *_jc_javax_net_ssl_SSLSocketFactory$method$createSocket$615da5ba7b09184c(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *, struct _jc_java_net_Socket$object *, struct _jc_java_lang_String$object *, jint, jboolean);
extern _jc_object_array *_jc_javax_net_ssl_SSLSocketFactory$method$getDefaultCipherSuites$09da17079d2c9bad(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *);
extern _jc_object_array *_jc_javax_net_ssl_SSLSocketFactory$method$getSupportedCipherSuites$f3b372cb435e53d6(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_SSLSocketFactory$method_info$createSocket$615da5ba7b09184c;
extern _jc_method _jc_javax_net_ssl_SSLSocketFactory$method_info$getDefaultCipherSuites$09da17079d2c9bad;
extern _jc_method _jc_javax_net_ssl_SSLSocketFactory$method_info$getSupportedCipherSuites$f3b372cb435e53d6;

// Static methods
extern struct _jc_javax_net_SocketFactory$object *_jc_javax_net_ssl_SSLSocketFactory$method$getDefault$895d615bd44dc4ed(_jc_env *);

// Virtual methods structure
struct _jc_javax_net_ssl_SSLSocketFactory$vmethods {
	struct _jc_java_net_Socket$object	*(*createSocket$615da5ba7b09184c)(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *, struct _jc_java_net_Socket$object *, struct _jc_java_lang_String$object *, jint, jboolean);
	_jc_object_array	*(*getDefaultCipherSuites$09da17079d2c9bad)(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *);
	_jc_object_array	*(*getSupportedCipherSuites$f3b372cb435e53d6)(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *);
};

// Vtable
struct _jc_javax_net_ssl_SSLSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_SocketFactory$vmethods	javax_net_SocketFactory;
	_jc_javax_net_ssl_SSLSocketFactory$vmethods	javax_net_ssl_SSLSocketFactory;
};

// Vtype
struct _jc_javax_net_ssl_SSLSocketFactory$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLSocketFactory$refs {
    _jc_javax_net_ssl_SSLSocketFactory$sub_refs	javax_net_ssl_SSLSocketFactory;
    _jc_javax_net_SocketFactory$sub_refs	javax_net_SocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_SocketFactory$sub_nonrefs	javax_net_SocketFactory;
    _jc_javax_net_ssl_SSLSocketFactory$sub_nonrefs	javax_net_ssl_SSLSocketFactory;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLSocketFactory$object {
	_jc_javax_net_ssl_SSLSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLSocketFactory$vtype	*vtype;
	_jc_javax_net_ssl_SSLSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLSocketFactory$vtype _jc_javax_net_ssl_SSLSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLSocketFactory$class_object;

#endif	/* _JC_javax_net_ssl_SSLSocketFactory_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/SSLSocketFactory.h <==
// public abstract class javax.net.ssl.SSLSocketFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ae720b2f6afde56 javax_net_SocketFactory
// @dep_class eb7a976ef44a2e8c javax_net_ssl_SSLSocketFactory

// header file dependencies
// @dep_header javax_net_SocketFactory

#include "javax/net/SocketFactory.h"

#ifndef _JC_javax_net_ssl_SSLSocketFactory_H_
#define _JC_javax_net_ssl_SSLSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_Socket$object;
struct _jc_javax_net_SocketFactory$object;
struct _jc_javax_net_ssl_SSLContext$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLSocketFactory$sub_refs	_jc_javax_net_ssl_SSLSocketFactory$sub_refs;
typedef struct _jc_javax_net_ssl_SSLSocketFactory$sub_nonrefs	_jc_javax_net_ssl_SSLSocketFactory$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLSocketFactory$refs	_jc_javax_net_ssl_SSLSocketFactory$refs;
typedef struct _jc_javax_net_ssl_SSLSocketFactory$nonrefs	_jc_javax_net_ssl_SSLSocketFactory$nonrefs;
typedef struct _jc_javax_net_ssl_SSLSocketFactory$object	_jc_javax_net_ssl_SSLSocketFactory$object;

typedef struct _jc_javax_net_ssl_SSLSocketFactory$fields_struct	_jc_javax_net_ssl_SSLSocketFactory$fields_struct;
typedef const struct _jc_javax_net_ssl_SSLSocketFactory$vmethods	_jc_javax_net_ssl_SSLSocketFactory$vmethods;
typedef const struct _jc_javax_net_ssl_SSLSocketFactory$vtable	_jc_javax_net_ssl_SSLSocketFactory$vtable;
typedef const struct _jc_javax_net_ssl_SSLSocketFactory$vtype	_jc_javax_net_ssl_SSLSocketFactory$vtype;

// Class fields structure
struct _jc_javax_net_ssl_SSLSocketFactory$fields_struct {
	struct _jc_javax_net_ssl_SSLContext$object	*context;
};
extern _jc_javax_net_ssl_SSLSocketFactory$fields_struct _jc_javax_net_ssl_SSLSocketFactory$class_fields;

// Constructors
extern void _jc_javax_net_ssl_SSLSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_net_Socket$object *_jc_javax_net_ssl_SSLSocketFactory$method$createSocket$615da5ba7b09184c(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *, struct _jc_java_net_Socket$object *, struct _jc_java_lang_String$object *, jint, jboolean) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_net_ssl_SSLSocketFactory$method$getDefaultCipherSuites$09da17079d2c9bad(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_net_ssl_SSLSocketFactory$method$getSupportedCipherSuites$f3b372cb435e53d6(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_SSLSocketFactory$method_info$createSocket$615da5ba7b09184c;
extern _jc_method _jc_javax_net_ssl_SSLSocketFactory$method_info$getDefaultCipherSuites$09da17079d2c9bad;
extern _jc_method _jc_javax_net_ssl_SSLSocketFactory$method_info$getSupportedCipherSuites$f3b372cb435e53d6;

// Static methods
extern struct _jc_javax_net_SocketFactory$object *_jc_javax_net_ssl_SSLSocketFactory$method$getDefault$895d615bd44dc4ed(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_net_ssl_SSLSocketFactory$vmethods {
	struct _jc_java_net_Socket$object	*(*createSocket$615da5ba7b09184c)(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *, struct _jc_java_net_Socket$object *, struct _jc_java_lang_String$object *, jint, jboolean) _JC_JCNI_ATTR;
	_jc_object_array	*(*getDefaultCipherSuites$09da17079d2c9bad)(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getSupportedCipherSuites$f3b372cb435e53d6)(_jc_env *, struct _jc_javax_net_ssl_SSLSocketFactory$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_ssl_SSLSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_SocketFactory$vmethods	javax_net_SocketFactory;
	_jc_javax_net_ssl_SSLSocketFactory$vmethods	javax_net_ssl_SSLSocketFactory;
};

// Vtype
struct _jc_javax_net_ssl_SSLSocketFactory$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLSocketFactory$refs {
    _jc_javax_net_ssl_SSLSocketFactory$sub_refs	javax_net_ssl_SSLSocketFactory;
    _jc_javax_net_SocketFactory$sub_refs	javax_net_SocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_SocketFactory$sub_nonrefs	javax_net_SocketFactory;
    _jc_javax_net_ssl_SSLSocketFactory$sub_nonrefs	javax_net_ssl_SSLSocketFactory;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLSocketFactory$object {
	_jc_javax_net_ssl_SSLSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLSocketFactory$vtype	*vtype;
	_jc_javax_net_ssl_SSLSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLSocketFactory$vtype _jc_javax_net_ssl_SSLSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLSocketFactory$class_object;

#endif	/* _JC_javax_net_ssl_SSLSocketFactory_H_ */
